@@ -1,8 +1,11 @@
+import os
 from blimpy import dice
 import pytest
 
 from tests.data import voyager_h5
 from tests.data import voyager_fil
+TEST_DATA_DIR = os.path.dirname(voyager_h5)
+HERE = os.getcwd()
 
 # This section makes sure that the tool exits correctly
 # when certain issues are encountered.
@@ -28,17 +31,26 @@ def test_missing_format_type():
 # file formats without exception.
 
 def test_h5():
+    os.chdir(TEST_DATA_DIR)
     args = ['-f', voyager_h5, '-b', '8419.24', '-e', '8419.35', '-x', 'h5', '-o', 'test_dice.h5']
     dice.cmd_tool(args)
+    os.chdir(HERE)
 
 def test_h5_no_out_file():
+    os.chdir(TEST_DATA_DIR)
     args = ['-f', voyager_h5, '-b', '8419.24', '-e', '8419.35', '-x', 'h5']
     dice.cmd_tool(args)
+    os.chdir(HERE)
 
 def test_fil():
+    os.chdir(TEST_DATA_DIR)
     args = ['-f', voyager_fil, '-b', '8419.24', '-e', '8419.35', '-x', 'fil', '-o', 'test_dice.fil']
     dice.cmd_tool(args)
+    os.chdir(HERE)
 
 def test_fil_no_out_file():
+    os.chdir(TEST_DATA_DIR)
     args = ['-f', voyager_fil, '-b', '8419.24', '-e', '8419.35', '-x', 'fil']
     dice.cmd_tool(args)
+    os.chdir(HERE)
+
